@@ -8,13 +8,6 @@
 
 #include <tokenizer.hpp>
 
-/**
- * switchAllowApostrophe Метод разрешения или запрещения апострофа как части слова
- */
-void anyks::Tokenizer::switchAllowApostrophe() noexcept {
-	// Выполняем переключение разрешения использования апострофа
-	this->apostrophe = !this->apostrophe;
-}
 /**
  * setAbbr Метод добавления аббревиатуры
  * @param word слово для добавления
@@ -95,21 +88,35 @@ const size_t anyks::Tokenizer::fti(const double num, const u_short count) const
 	return result;
 }
 /**
- * isAllowApostrophe Метод проверки разрешения апострофа
- * @return результат проверки
+ * isAbbr Метод проверки слова на соответствие аббревиатуры
+ * @param  word слово для проверки
+ * @return      результат проверки
  */
-const bool anyks::Tokenizer::isAllowApostrophe() const noexcept {
-	// Выводим результат проверки апострофа
-	return this->apostrophe;
-}
-/**
- * idw Метод извлечения идентификатора слова
- * @param  word слово для получения идентификатора
- * @return      идентификатор слова
- */
-const size_t anyks::Tokenizer::idw(const wstring & word) const noexcept {
-	// Формируем идентификатор слова
-	return this->idWord.get(word);
+const bool anyks::Tokenizer::isAbbr(const wstring & word) const noexcept {
+	// Результат работы функции
+	bool result = false;
+	// Если слово передано
+	if(!word.empty() && !this->abbrs.empty()){
+		// Позиция точки в слове
+		size_t pos = 0;
+		// Слово для проверки
+		wstring tmp = L"";
+		// Выполняем поиск точки
+		if((pos = word.find(L'.')) != wstring::npos){
+			// Обрезаем слово до точки
+			tmp = word.substr(0, pos);
+		// Иначе запоминаем слово как оно есть
+		} else tmp = move(word);
+		// Если слово не пустое
+		if(!tmp.empty()){
+			// Получаем идентификатор слова
+			const size_t idw = this->idw(tmp);
+			// Выполняем проверку сущестования аббревиатуры
+			result = (this->abbrs.count(idw) > 0);
+		}
+	}
+	// Выводим результат
+	return result;
 }
 /**
  * idt Метод извлечения идентификатора токена
@@ -278,35 +285,22 @@ const anyks::token_t anyks::Tokenizer::idt(const wstring & word) const noexcept
 	return result;
 }
 /**
- * isAbbr Метод проверки слова на соответствие аббревиатуры
- * @param  word слово для проверки
- * @return      результат проверки
+ * idw Метод извлечения идентификатора слова
+ * @param  word слово для получения идентификатора
+ * @return      идентификатор слова
  */
-const bool anyks::Tokenizer::isAbbr(const wstring & word) const noexcept {
-	// Результат работы функции
-	bool result = false;
-	// Если слово передано
-	if(!word.empty() && !this->abbrs.empty()){
-		// Позиция точки в слове
-		size_t pos = 0;
-		// Слово для проверки
-		wstring tmp = L"";
-		// Выполняем поиск точки
-		if((pos = word.find(L'.')) != wstring::npos){
-			// Обрезаем слово до точки
-			tmp = word.substr(0, pos);
-		// Иначе запоминаем слово как оно есть
-		} else tmp = move(word);
-		// Если слово не пустое
-		if(!tmp.empty()){
-			// Получаем идентификатор слова
-			const size_t idw = this->idw(tmp);
-			// Выполняем проверку сущестования аббревиатуры
-			result = (this->abbrs.count(idw) > 0);
-		}
-	}
-	// Выводим результат
-	return result;
+const size_t anyks::Tokenizer::idw(const wstring & word) const noexcept {
+	// Формируем идентификатор слова
+	return this->idWord.get(word);
+}
+/**
+ * ids Метод извлечения идентификатора последовательности
+ * @param  seq последовательность для получения идентификатора
+ * @return     идентификатор последовательности
+ */
+const size_t anyks::Tokenizer::ids(const vector <size_t> & seq) const noexcept {
+	// Формируем идентификатор последовательности
+	return this->idWord.get(seq);
 }
 /**
  * readline Метод извлечения строки из текста
@@ -461,7 +455,7 @@ const string anyks::Tokenizer::restore(const vector <string> & context) const no
 						// Если предыдущий символ не является открытым изоляционнмы символом
 						if((typeContext.empty() ||
 						(typeContext.top() != type_t::open)) &&
-						(text.back() != L' ') &&
+						(!this->alphabet->isSpace(text.back())) &&
 						(!this->alphabet->isNumber(token.substr(0, 1)) ||
 						!this->alphabet->isMath(text.back()) ||
 						(text.back() == L'='))) text.append(1, L' ');
@@ -480,7 +474,7 @@ const string anyks::Tokenizer::restore(const vector <string> & context) const no
 						(typeContext.top() != type_t::math) &&
 						(typeContext.top() != type_t::open) &&
 						(typeContext.top() != type_t::space))) &&
-						(text.back() != L' ')) text.append(1, L' ');
+						(!this->alphabet->isSpace(text.back()))) text.append(1, L' ');
 						// Добавляем слово
 						text.append(token);
 					} break;
@@ -491,7 +485,7 @@ const string anyks::Tokenizer::restore(const vector <string> & context) const no
 						((typeContext.top() != type_t::specl) &&
 						(typeContext.top() != type_t::open) &&
 						(typeContext.top() != type_t::space))) &&
-						(text.back() != L' ')) text.append(1, L' ');
+						(!this->alphabet->isSpace(text.back()))) text.append(1, L' ');
 						// Добавляем слово
 						text.append(token);
 					} break;
@@ -516,7 +510,7 @@ const string anyks::Tokenizer::restore(const vector <string> & context) const no
 						// Если предыдущий символ не является изоляционным символом
 						if((typeContext.empty() ||
 						(typeContext.top() != type_t::space)) &&
-						(text.back() != L' ')) text.append(1, L' ');
+						(!this->alphabet->isSpace(text.back()))) text.append(1, L' ');
 						// Добавляем слово
 						text.append(token);
 						// Если следующий символ является любым из слов кроме изоляционного символа и конца текста
@@ -646,7 +640,7 @@ const wstring anyks::Tokenizer::restore(const vector <wstring> & context) const
 						// Если предыдущий символ не является открытым изоляционнмы символом
 						if((typeContext.empty() ||
 						(typeContext.top() != type_t::open)) &&
-						(result.back() != L' ') &&
+						(!this->alphabet->isSpace(result.back())) &&
 						(!this->alphabet->isNumber(token.substr(0, 1)) ||
 						!this->alphabet->isMath(result.back()) ||
 						(result.back() == L'='))) result.append(1, L' ');
@@ -665,7 +659,7 @@ const wstring anyks::Tokenizer::restore(const vector <wstring> & context) const
 						(typeContext.top() != type_t::math) &&
 						(typeContext.top() != type_t::open) &&
 						(typeContext.top() != type_t::space))) &&
-						(result.back() != L' ')) result.append(1, L' ');
+						(!this->alphabet->isSpace(result.back()))) result.append(1, L' ');
 						// Добавляем слово
 						result.append(token);
 					} break;
@@ -676,7 +670,7 @@ const wstring anyks::Tokenizer::restore(const vector <wstring> & context) const
 						((typeContext.top() != type_t::specl) &&
 						(typeContext.top() != type_t::open) &&
 						(typeContext.top() != type_t::space))) &&
-						(result.back() != L' ')) result.append(1, L' ');
+						(!this->alphabet->isSpace(result.back()))) result.append(1, L' ');
 						// Добавляем слово
 						result.append(token);
 					} break;
@@ -701,7 +695,7 @@ const wstring anyks::Tokenizer::restore(const vector <wstring> & context) const
 						// Если предыдущий символ не является изоляционным символом
 						if((typeContext.empty() ||
 						(typeContext.top() != type_t::space)) &&
-						(result.back() != L' ')) result.append(1, L' ');
+						(!this->alphabet->isSpace(result.back()))) result.append(1, L' ');
 						// Добавляем слово
 						result.append(token);
 						// Если следующий символ является любым из слов кроме изоляционного символа и конца текста
@@ -1092,7 +1086,7 @@ void anyks::Tokenizer::run(const wstring & text, function <const bool (const wst
 						}
 					}
 				// Если это изоляционный символ
-				} else if(this->alphabet->isIsolation(lletter) && (!this->isAllowApostrophe() || (lletter != L'\''))) {
+				} else if(this->alphabet->isIsolation(lletter) && (!this->alphabet->isAllowApostrophe() || (lletter != L'\''))) {
 					// Выводим результат как он есть
 					if(end){
 						// Если слово не пустое
