@@ -77,8 +77,8 @@ namespace anyks {
 	alphabet_t alphabet;
 	// Создаём объект токенизатора
 	tokenizer_t tokenizer(&alphabet);
-	// Создаём объект языковой модели
-	alm_t alm(&alphabet, &tokenizer);
+	// Создаём обхъект языковой модели
+	unique_ptr <alm_t> alm(new alm1_t(&alphabet, &tokenizer));
 	/**
 	 * Methods Основные методы библиотеки
 	 */
@@ -124,7 +124,7 @@ namespace anyks {
 		 */
 		void setUnknown(const wstring & word) noexcept {
 			// Выполняем установку неизвестного слова
-			alm.setUnknown(alphabet.convert(word));
+			alm->setUnknown(alphabet.convert(word));
 		}
 		/**
 		 * getName Метод извлечения названия библиотеки
@@ -140,7 +140,7 @@ namespace anyks {
 		 */
 		void sentences(function <const bool (const wstring &)> callback) noexcept {
 			// Выполняем генерацию предложений
-			alm.sentences(callback);
+			alm->sentences(callback);
 		}
 		/**
 		 * getEmail Метод извлечения электронной почты автора
@@ -173,7 +173,7 @@ namespace anyks {
 		 */
 		void findNgram(const wstring & text, function <void (const wstring &)> callback) noexcept {
 			// Выполняем поиск n-грамм в тексте
-			alm.find(text, callback);
+			alm->find(text, callback);
 		}
 		/**
 		 * setOption Метод установки опций модуля
@@ -181,7 +181,7 @@ namespace anyks {
 		 */
 		void setOption(const alm_t::options_t option) noexcept {
 			// Выполняем установку опций модуля
-			alm.setOption(option);
+			alm->setOption(option);
 		}
 		/**
 		 * getUnknown Метод извлечения неизвестного слова
@@ -189,7 +189,7 @@ namespace anyks {
 		 */
 		const wstring getUnknown() noexcept {
 			// Выводим результат
-			return alphabet.convert(alm.getUnknown());
+			return alphabet.convert(alm->getUnknown());
 		}
 		/**
 		 * size Метод получения размера n-грамы
@@ -197,7 +197,7 @@ namespace anyks {
 		 */
 		const size_t size() noexcept {
 			// Выводим результат
-			return alm.getSize();
+			return alm->getSize();
 		}
 		/**
 		 * jsonToText Метод преобразования текста в формате json в текст
@@ -238,7 +238,7 @@ namespace anyks {
 		 */
 		void unsetOption(const alm_t::options_t option) noexcept {
 			// Выполняем отключение опции модуля
-			alm.unsetOption(option);
+			alm->unsetOption(option);
 		}
 		/**
 		 * getBadwords Метод извлечения чёрного списка
@@ -246,7 +246,7 @@ namespace anyks {
 		 */
 		const set <size_t> & getBadwords() noexcept {
 			// Выводим результат
-			return alm.getBadwords();
+			return alm->getBadwords();
 		}
 		/**
 		 * setUserToken Метод добавления токена пользователя
@@ -254,7 +254,7 @@ namespace anyks {
 		 */
 		void setUserToken(const wstring & name) noexcept {
 			// Выполняем добавление токена пользователя
-			alm.setUserToken(alphabet.convert(name));
+			alm->setUserToken(alphabet.convert(name));
 		}
 		/**
 		 * getGoodwords Метод извлечения белого списка
@@ -262,14 +262,7 @@ namespace anyks {
 		 */
 		const set <size_t> & getGoodwords() noexcept {
 			// Выводим результат
-			return alm.getGoodwords();
-		}
-		/**
-		 * initScripts Метод инициализации скриптов питона
-		 */
-		void initScripts() noexcept {
-			// Выполняем инициализацию скриптов питона
-			alm.initPython();
+			return alm->getGoodwords();
 		}
 		/**
 		 * setLogfile Метод установки файла для вывода логов
@@ -281,7 +274,7 @@ namespace anyks {
 				// Запоминаем адрес файла логов
 				logfile = alphabet.convert(file);
 				// Выполняем установку файла для вывода логов
-				alm.setLogfile(logfile.c_str());
+				alm->setLogfile(logfile.c_str());
 			}
 		}
 		/**
@@ -290,7 +283,7 @@ namespace anyks {
 		 */
 		void setOOvFile(const wstring & oovfile) noexcept {
 			// Выполняем установку файла для сохранения OOV слов
-			if(!oovfile.empty()) alm.setOOvFile(alphabet.convert(oovfile).c_str());
+			if(!oovfile.empty()) alm->setOOvFile(alphabet.convert(oovfile).c_str());
 		}
 		/**
 		 * pplConcatenate Метод объединения перплексий
@@ -300,7 +293,7 @@ namespace anyks {
 		 */
 		const alm_t::ppl_t pplConcatenate(const alm_t::ppl_t & ppl1, const alm_t::ppl_t & ppl2) noexcept {
 			// Выполняем расчёт перплексии
-			return alm.pplConcatenate(ppl1, ppl2);
+			return alm->pplConcatenate(ppl1, ppl2);
 		}
 		/**
 		 * getUserTokens Метод извлечения списка пользовательских токенов
@@ -310,7 +303,7 @@ namespace anyks {
 			// Результат работы функции
 			vector <wstring> result;
 			// Получаем список токенов
-			const auto & tokens = alm.getUserTokens();
+			const auto & tokens = alm->getUserTokens();
 			// Если токены получены
 			if(!tokens.empty()){
 				// Переходим по списку токенов
@@ -347,7 +340,7 @@ namespace anyks {
 		 */
 		const wstring fixUppers(const wstring & text) noexcept {
 			// Выполняем исправление регистров в тексте
-			return alm.fixUppers(text);
+			return alm->fixUppers(text);
 		}
 		/**
 		 * checkHypLat Метод поиска дефиса и латинского символа
@@ -358,14 +351,6 @@ namespace anyks {
 			// Выводим результат првоерки
 			return alphabet.checkHypLat(str);
 		}
-		/**
-		 * setWordScript Метод установки скрипта обработки слов
-		 * @param script скрипт python обработки слов
-		 */
-		void setWordScript(const wstring & script) noexcept {
-			// Выполняем установку скрипта обработки слов
-			alm.setWordScript(alphabet.convert(script));
-		}
 		/**
 		 * getContact Метод извлечения контактных данных автора
 		 * @return контактные данные автора
@@ -383,7 +368,7 @@ namespace anyks {
 			// Создаём список регистров
 			vector <size_t> upps;
 			// Выполняем извлечение регистров для каждого слова
-			alm.getUppers(seq, upps);
+			alm->getUppers(seq, upps);
 			// Выводим список регистров
 			return upps;
 		}
@@ -412,14 +397,6 @@ namespace anyks {
 			// Выводим координаты url адреса
 			return alphabet.urls(text);
 		}
-		/**
-		 * getWordScript Метод извлечения скрипта обработки слов
-		 * @return адрес скрипта python обработки слов
-		 */
-		const wstring getWordScript() noexcept {
-			// Выводим результат
-			return alphabet.convert(alm.getWordScript());
-		}
 		/**
 		 * getVersion Метод получения версии языковой модели
 		 * @return версия языковой модели
@@ -434,7 +411,7 @@ namespace anyks {
 		 */
 		const bool isAllowApostrophe() noexcept {
 			// Выводрим результат проверки
-			return tokenizer.isAllowApostrophe();
+			return alphabet.isAllowApostrophe();
 		}
 		/**
 		 * getUserTokenId Метод получения идентификатора пользовательского токена
@@ -443,7 +420,7 @@ namespace anyks {
 		 */
 		const size_t getUserTokenId(const wstring & name) noexcept {
 			// Выводим результат
-			return alm.getUserTokenId(alphabet.convert(name));
+			return alm->getUserTokenId(alphabet.convert(name));
 		}
 		/**
 		 * roman2Arabic Метод перевода римских цифр в арабские
@@ -479,31 +456,23 @@ namespace anyks {
 				// Переходим по всему списку токенов
 				for(auto & token : tokens) tmp.emplace(token_t(token));
 				// Выполняем установку списка запрещённых токенов
-				alm.setTokensDisable(tmp);
+				alm->setTokensDisable(tmp);
 			}
 		}
-		/**
-		 * setUserTokenScript Метод установки скрипта обработки пользовательских токенов
-		 * @param script скрипт python обработки пользовательских токенов
-		 */
-		void setUserTokenScript(const wstring & script) noexcept {
-			// Выполняем установку скрипта обработки пользовательских токенов
-			alm.setUserTokenScript(alphabet.convert(script));
-		}
 		/**
 		 * setTokenDisable Метод установки списка не идентифицируемых токенов
 		 * @param options список не идентифицируемых токенов
 		 */
 		void setTokenDisable(const wstring & options) noexcept {
 			// Выполняем установку списка не идентифицируемых токенов
-			alm.setTokenDisable(alphabet.convert(options));
+			alm->setTokenDisable(alphabet.convert(options));
 		}
 		/**
 		 * setAllTokenDisable Метод установки всех токенов как не идентифицируемых
 		 */
 		void setAllTokenDisable() noexcept {
 			// Выполняем установку всех токенов как не идентифицируемых
-			alm.setAllTokenDisable();
+			alm->setAllTokenDisable();
 		}
 		/**
 		 * setTokensUnknown Метод установки списка токенов приводимых к <unk>
@@ -517,7 +486,7 @@ namespace anyks {
 				// Переходим по всему списку токенов
 				for(auto & token : tokens) tmp.emplace(token_t(token));
 				// Выполняем установку списка токенов приводимых к <unk>
-				alm.setTokensUnknown(tmp);
+				alm->setTokensUnknown(tmp);
 			}
 		}
 		/**
@@ -528,7 +497,7 @@ namespace anyks {
 			// Результат работы функции
 			set <size_t> result;
 			// Извлекаем список токенов
-			const auto & tokens = alm.getTokensDisable();
+			const auto & tokens = alm->getTokensDisable();
 			// Если список токенов получен
 			if(!tokens.empty()){
 				// Переходим по всему списку токенов
@@ -552,7 +521,7 @@ namespace anyks {
 		 */
 		void setAllTokenUnknown() noexcept {
 			// Выполняем установку всех токенов идентифицируемых как <unk>
-			alm.setAllTokenUnknown();
+			alm->setAllTokenUnknown();
 		}
 		/**
 		 * countAlphabet Метод получения количества букв в словаре
@@ -569,7 +538,7 @@ namespace anyks {
 		 */
 		const wstring getUserTokenWord(const size_t idw) noexcept {
 			// Выводим результат
-			return alphabet.convert(alm.getUserTokenWord(idw));
+			return alphabet.convert(alm->getUserTokenWord(idw));
 		}
 		/**
 		 * setWordPreprocessingMethod Метод установки функции препроцессинга слова
@@ -577,7 +546,7 @@ namespace anyks {
 		 */
 		void setWordPreprocessingMethod(function <const string (const string &, const vector <string> &)> fn) noexcept {
 			// Устанавливаем функцию
-			alm.setWordPreprocessingMethod(fn);
+			alm->setWordPreprocessingMethod(fn);
 		}
 		/**
 		 * setUserTokenMethod Метод установки функции обработки пользовательского токена
@@ -586,7 +555,7 @@ namespace anyks {
 		 */
 		void setUserTokenMethod(const wstring & name, function <const bool (const string &, const string &)> fn) noexcept {
 			// Выполняем добавление функции обработки пользовательского токена
-			alm.setUserTokenMethod(alphabet.convert(name), fn);
+			alm->setUserTokenMethod(alphabet.convert(name), fn);
 		}
 		/**
 		 * setSubstitutes Метод установки букв для исправления слов из смешанных алфавитов
@@ -609,14 +578,6 @@ namespace anyks {
 				alphabet.setSubstitutes(tmp);
 			}
 		}
-		/**
-		 * getUserTokenScript Метод извлечения скрипта обработки пользовательских токенов
-		 * @return адрес скрипта python обработки пользовательских токенов
-		 */
-		const wstring getUserTokenScript() noexcept {
-			// Выводим результат
-			return alphabet.convert(alm.getUserTokenScript());
-		}
 		/**
 		 * getTokensUnknown Метод извлечения списка токенов приводимых к <unk>
 		 * @return список токенов
@@ -625,7 +586,7 @@ namespace anyks {
 			// Результат работы функции
 			set <size_t> result;
 			// Извлекаем список токенов
-			const auto & tokens = alm.getTokensUnknown();
+			const auto & tokens = alm->getTokensUnknown();
 			// Если список токенов получен
 			if(!tokens.empty()){
 				// Переходим по всему списку токенов
@@ -663,14 +624,14 @@ namespace anyks {
 		 */
 		void setTokenUnknown(const wstring & options) noexcept {
 			// Выполняем установку списка токенов которых нужно идентифицировать как <unk>
-			alm.setTokenUnknown(alphabet.convert(options));
+			alm->setTokenUnknown(alphabet.convert(options));
 		}
 		/**
 		 * switchAllowApostrophe Метод разрешения или запрещения апострофа как части слова
 		 */
 		void switchAllowApostrophe() noexcept {
 			// Выполняем переключение разрешения апострофа
-			tokenizer.switchAllowApostrophe();
+			alphabet.switchAllowApostrophe();
 		}
 		/**
 		 * addBadword Метод добавления идентификатора похого слова в список
@@ -678,7 +639,7 @@ namespace anyks {
 		 */
 		void addBadword(const size_t idw) noexcept {
 			// Выполняем добавление идентификатора похого слова в список
-			alm.addBadword(idw);
+			alm->addBadword(idw);
 		}
 		/**
 		 * addBadword Метод добавления похого слова в список
@@ -686,7 +647,7 @@ namespace anyks {
 		 */
 		void addBadword(const wstring & word) noexcept {
 			// Выполняем добавление похого слова в список
-			alm.addBadword(alphabet.convert(word));
+			alm->addBadword(alphabet.convert(word));
 		}
 		/**
 		 * addGoodword Метод добавления идентификатора хорошего слова в список
@@ -694,7 +655,7 @@ namespace anyks {
 		 */
 		void addGoodword(const size_t idw) noexcept {
 			// Выполняем добавление идентификатора хорошего слова в список
-			alm.addGoodword(idw);
+			alm->addGoodword(idw);
 		}
 		/**
 		 * addGoodword Метод добавления хорошего слова в список
@@ -702,7 +663,7 @@ namespace anyks {
 		 */
 		void addGoodword(const wstring & word) noexcept {
 			// Выполняем добавление хорошего слова в список
-			alm.addGoodword(alphabet.convert(word));
+			alm->addGoodword(alphabet.convert(word));
 		}
 		/**
 		 * countBigrams Метод проверки количества найденных в тексте биграмм
@@ -711,7 +672,7 @@ namespace anyks {
 		 */
 		const size_t countBigrams(const wstring & text) noexcept {
 			// Выводим результат
-			return alm.bigrams(alphabet.convert(text));
+			return alm->bigrams(alphabet.convert(text));
 		}
 		/**
 		 * perplexity Метод расчёта перплексии текста
@@ -720,7 +681,7 @@ namespace anyks {
 		 */
 		const alm_t::ppl_t perplexity(const wstring & text) noexcept {
 			// Выполняем расчёт перплексии
-			return alm.perplexity(text);
+			return alm->perplexity(text);
 		}
 		/**
 		 * countTrigrams Метод проверки количества найденных в тексте триграмм
@@ -729,7 +690,7 @@ namespace anyks {
 		 */
 		const size_t countTrigrams(const wstring & text) noexcept {
 			// Выводим результат
-			return alm.trigrams(alphabet.convert(text));
+			return alm->trigrams(alphabet.convert(text));
 		}
 		/**
 		 * setBadwords Метод установки списка идентификаторов плохих слов в список
@@ -737,7 +698,7 @@ namespace anyks {
 		 */
 		void setBadwords(const set <size_t> & idws) noexcept {
 			// Выполняем установку списка идентификаторов плохих слов в список
-			alm.setBadwords(idws);
+			alm->setBadwords(idws);
 		}
 		/**
 		 * setBadwords Метод установки списка плохих слов в список
@@ -749,7 +710,7 @@ namespace anyks {
 			// Формируем новый список
 			for(auto & word : badwords) tmp.push_back(alphabet.convert(word));
 			// Выполняем установку списка плохих слов в список
-			alm.setBadwords(tmp);
+			alm->setBadwords(tmp);
 		}
 		/**
 		 * setGoodwords Метод установки списка идентификаторов хороших слов в список
@@ -757,7 +718,7 @@ namespace anyks {
 		 */
 		void setGoodwords(const set <size_t> & idws) noexcept {
 			// Выполняем установку списка идентификаторов хороших слов в список
-			alm.setGoodwords(idws);
+			alm->setGoodwords(idws);
 		}
 		/**
 		 * setGoodwords Метод установки списка хороших слов в список
@@ -769,7 +730,7 @@ namespace anyks {
 			// Формируем новый список
 			for(auto & word : goodwords) tmp.push_back(alphabet.convert(word));
 			// Выполняем установку списка хороших слов в список
-			alm.setGoodwords(tmp);
+			alm->setGoodwords(tmp);
 		}
 		/**
 		 * countGrams Метод проверки количества найденных в тексте n-грамм
@@ -778,7 +739,7 @@ namespace anyks {
 		 */
 		const size_t countGrams(const wstring & text) noexcept {
 			// Выводим результат
-			return alm.grams(alphabet.convert(text));
+			return alm->grams(alphabet.convert(text));
 		}
 		/**
 		 * countBigrams Метод проверки количества найденных биграмм
@@ -787,7 +748,7 @@ namespace anyks {
 		 */
 		const size_t countBigrams(const vector <size_t> & seq) noexcept {
 			// Выводим результат
-			return alm.bigrams(seq);
+			return alm->bigrams(seq);
 		}
 		/**
 		 * perplexity Метод расчёта перплексии
@@ -796,7 +757,7 @@ namespace anyks {
 		 */
 		const alm_t::ppl_t perplexity(const vector <size_t> & seq) noexcept {
 			// Выполняем расчёт перплексии
-			return alm.perplexity(seq);
+			return alm->perplexity(seq);
 		}
 		/**
 		 * countTrigrams Метод проверки количества найденных триграмм
@@ -805,7 +766,7 @@ namespace anyks {
 		 */
 		const size_t countTrigrams(const vector <size_t> & seq) noexcept {
 			// Выводим результат
-			return alm.trigrams(seq);
+			return alm->trigrams(seq);
 		}
 		/**
 		 * countGrams Метод проверки количества найденных n-грамм
@@ -814,7 +775,7 @@ namespace anyks {
 		 */
 		const size_t countGrams(const vector <size_t> & seq) noexcept {
 			// Выводим результат
-			return alm.grams(seq);
+			return alm->grams(seq);
 		}
 		/**
 		 * arabic2Roman Метод перевода арабских чисел в римские
@@ -842,6 +803,15 @@ namespace anyks {
 			// Устанавливаем локаль
 			alphabet.setlocale(alphabet.convert(text));
 		}
+		/**
+		 * ids Метод извлечения идентификатора последовательности
+		 * @param  seq последовательность для получения идентификатора
+		 * @return     идентификатор последовательности
+		 */
+		const size_t ids(const vector <size_t> & seq) noexcept {
+			// Выводим идентификатор последовательности
+			return tokenizer.ids(seq);
+		}
 		/**
 		 * idw Метод извлечения идентификатора слова
 		 * @param  word  слово для получения идентификатора
@@ -850,7 +820,7 @@ namespace anyks {
 		 */
 		const size_t idw(const wstring & word, const bool check = true) noexcept {
 			// Выводим идентификатор слова
-			return alm.getIdw(word, check);
+			return alm->getIdw(word, check);
 		}
 		/**
 		 * setThreads Метод установки количества потоков
@@ -858,7 +828,7 @@ namespace anyks {
 		 */
 		void setThreads(const size_t threads = 0) noexcept {
 			// Выполняем установку количества потоков
-			alm.setThreads(threads);
+			alm->setThreads(threads);
 		}
 		/**
 		 * clear Метод очистки
@@ -869,18 +839,18 @@ namespace anyks {
 				// Выполняем полную очистку
 				case u_short(clear_t::all): {
 					// Выполняем очистику языковой модели
-					alm.clear();
+					alm->clear();
 					// Выполняем очистику алфавита
 					alphabet.clear();
 					// Выполняем очистку токенизатора
 					tokenizer.clear();
 				} break;
 				// Выполняем очистку чёрного списка слов
-				case u_short(clear_t::badwords): alm.clearBadwords(); break;
+				case u_short(clear_t::badwords): alm->clearBadwords(); break;
 				// Выполняем очистку пользовательских токенов
-				case u_short(clear_t::utokens): alm.clearUserTokens(); break;
+				case u_short(clear_t::utokens): alm->clearUserTokens(); break;
 				// Выполняем очистку белого списка слов
-				case u_short(clear_t::goodwords): alm.clearGoodwords(); break;
+				case u_short(clear_t::goodwords): alm->clearGoodwords(); break;
 			}
 		}
 		/**
@@ -901,7 +871,7 @@ namespace anyks {
 		 */
 		const wstring context(const vector <size_t> & seq, const bool nwrd = false) noexcept {
 			// Выполняем сборку текстового контекста из последовательности
-			return alm.context(seq, nwrd);
+			return alm->context(seq, nwrd);
 		}
 		/**
 		 * readLM Метод чтения данных из файла arpa
@@ -914,7 +884,7 @@ namespace anyks {
 				// Если это бинарный контейнер
 				if(filename.rfind(L".alm") != wstring::npos){
 					// Создаём объект бинарного контейнера
-					ablm_t ablm(alphabet.convert(filename), &alm, &alphabet, &tokenizer, (!logfile.empty() ? logfile.c_str() : nullptr));
+					ablm_t ablm(alphabet.convert(filename), alm.get(), &alphabet, &tokenizer, (!logfile.empty() ? logfile.c_str() : nullptr));
 					// Если метеданные получены
 					if(!meta.empty()) ablm.setMeta(json::parse(alphabet.convert(meta)));
 					// Выполняем инициализацию словаря
@@ -922,7 +892,7 @@ namespace anyks {
 					// Выполняем чтение бинарных данных
 					ablm.readAlm();
 				// Иначе если это arpa, загружаем обычным способом
-				} else alm.read(alphabet.convert(filename));
+				} else alm->read(alphabet.convert(filename));
 			}
 		}
 		/**
@@ -933,7 +903,7 @@ namespace anyks {
 		 */
 		const pair <bool, size_t> checkSequence(const wstring & text, const bool accurate = false) noexcept {
 			// Выполняем проверку существования последовательности
-			return alm.check(text, accurate);
+			return alm->check(text, accurate);
 		}
 		/**
 		 * check Метод проверки строки
@@ -1009,7 +979,7 @@ namespace anyks {
 		 */
 		void findByFiles(const wstring & path, const wstring & filename, const wstring & ext = L"txt") noexcept {
 			// Выполняем поиск n-грамм в текстовом файле
-			alm.findByFiles(alphabet.convert(path), alphabet.convert(filename), nullptr, alphabet.convert(ext));
+			alm->findByFiles(alphabet.convert(path), alphabet.convert(filename), nullptr, alphabet.convert(ext));
 		}
 		/**
 		 * pplByFiles Метод чтения расчёта перплексии по файлу или группе файлов
@@ -1019,7 +989,7 @@ namespace anyks {
 		 */
 		const alm_t::ppl_t pplByFiles(const wstring & path, const wstring & ext = L"txt") noexcept {
 			// Выполняем расчёт перплексии
-			return alm.pplByFiles(alphabet.convert(path), nullptr, alphabet.convert(ext));
+			return alm->pplByFiles(alphabet.convert(path), nullptr, alphabet.convert(ext));
 		}
 		/**
 		 * delInText Метод очистки текста
@@ -1048,7 +1018,7 @@ namespace anyks {
 		 */
 		const pair <bool, size_t> checkSequence(const vector <size_t> & seq, const bool accurate = false) noexcept {
 			// Выполняем проверку существования последовательности
-			return alm.check(seq, accurate);
+			return alm->check(seq, accurate);
 		}
 		/**
 		 * sentencesToFile Метод сборки указанного количества предложений и записи в файл
@@ -1057,7 +1027,7 @@ namespace anyks {
 		 */
 		void sentencesToFile(const size_t counts, const wstring & filename) noexcept {
 			// Выполняем сборку указанного количества предложений
-			alm.sentencesToFile(counts, alphabet.convert(filename));
+			alm->sentencesToFile(counts, alphabet.convert(filename));
 		}
 		/**
 		 * fixUppersByFiles Метод исправления регистров текста в текстовом файле
@@ -1067,7 +1037,7 @@ namespace anyks {
 		 */
 		void fixUppersByFiles(const wstring & path, const wstring & filename, const wstring & ext = L"txt") noexcept {
 			// Выполняем исправление регистров текста
-			alm.fixUppersByFiles(alphabet.convert(path), alphabet.convert(filename), nullptr, alphabet.convert(ext));
+			alm->fixUppersByFiles(alphabet.convert(path), alphabet.convert(filename), nullptr, alphabet.convert(ext));
 		}
 		/**
 		 * countsByFiles Метод подсчёта количества n-грамм в текстовом файле
@@ -1078,7 +1048,7 @@ namespace anyks {
 		 */
 		void countsByFiles(const wstring & path, const wstring & filename, const u_short ngrams = 0, const wstring & ext = L"txt") noexcept {
 			// Выполняем подсчёт количества n-грамм
-			alm.countsByFiles(alphabet.convert(path), alphabet.convert(filename), ngrams, nullptr, alphabet.convert(ext));
+			alm->countsByFiles(alphabet.convert(path), alphabet.convert(filename), ngrams, nullptr, alphabet.convert(ext));
 		}
 		/**
 		 * checkByFiles Метод проверки существования последовательности в текстовом файле
@@ -1089,7 +1059,7 @@ namespace anyks {
 		 */
 		void checkByFiles(const wstring & path, const wstring & filename, const bool accurate = false, const wstring & ext = L"txt") noexcept {
 			// Выполняем проверку существования последовательности
-			alm.checkByFiles(alphabet.convert(path), alphabet.convert(filename), accurate, nullptr, alphabet.convert(ext));
+			alm->checkByFiles(alphabet.convert(path), alphabet.convert(filename), accurate, nullptr, alphabet.convert(ext));
 		}
 	};
 };
@@ -1158,6 +1128,8 @@ PYBIND11_MODULE(alm, m) {
 	{
 		// idt Метод извлечения идентификатора токена
 		m.def("idt", &anyks::Methods::idt, "Token ID retrieval method")
+		// ids Метод извлечения идентификатора последовательности
+		.def("ids", &anyks::Methods::ids, "Sequence ID retrieval method")
 		// setZone Метод установки пользовательской зоны
 		.def("setZone", &anyks::Methods::setZone, "User zone set method")
 		// setAbbr Метод добавления аббревиатуры
@@ -1198,8 +1170,6 @@ PYBIND11_MODULE(alm, m) {
 		.def("setUserToken", &anyks::Methods::setUserToken, "Method for adding user token")
 		// getGoodwords Метод извлечения белого списка
 		.def("getGoodwords", &anyks::Methods::getGoodwords, "Method get words in whitelist")
-		// initScripts Метод инициализации скриптов питона
-		.def("initScripts", &anyks::Methods::initScripts, "Python script initialization method")
 		// setLogfile Метод установки файла для вывода логов
 		.def("setLogfile", &anyks::Methods::setLogfile, "Method of set the file for log output")
 		// setOOvFile Метод установки файла для сохранения OOV слов
@@ -1214,10 +1184,6 @@ PYBIND11_MODULE(alm, m) {
 		.def("fixUppers", &anyks::Methods::fixUppers, "Method for correcting registers in the text")
 		// checkHypLat Метод поиска дефиса и латинского символа
 		.def("checkHypLat", &anyks::Methods::checkHypLat, "Hyphen and latin character search method")
-		// setWordScript Метод установки скрипта обработки слов
-		.def("setWordScript", &anyks::Methods::setWordScript, "Method set script of word processing")
-		// getWordScript Метод извлечения скрипта обработки слов
-		.def("getWordScript", &anyks::Methods::getWordScript, "Method set script of word processing")
 		// getContact Метод извлечения контактных данных автора
 		.def("getContact", &anyks::Methods::getContact, "Author contact information retrieval method")
 		// getSite Метод извлечения адреса сайта автора
@@ -1238,8 +1204,6 @@ PYBIND11_MODULE(alm, m) {
 		.def("rest", &anyks::Methods::rest, "Method for correction and detection of words with mixed alphabets")
 		// setTokensDisable Метод установки списка запрещённых токенов
 		.def("setTokensDisable", &anyks::Methods::setTokensDisable, "Method for set the list of forbidden tokens")
-		// setUserTokenScript Метод установки скрипта обработки пользовательских токенов
-		.def("setUserTokenScript", &anyks::Methods::setUserTokenScript, "Method set script user token processing")
 		// setTokenDisable Метод установки списка не идентифицируемых токенов
 		.def("setTokenDisable", &anyks::Methods::setTokenDisable, "Method for set the list of unidentifiable tokens")
 		// setAllTokenDisable Метод установки всех токенов как не идентифицируемых
@@ -1260,8 +1224,6 @@ PYBIND11_MODULE(alm, m) {
 		.def("setUserTokenMethod", &anyks::Methods::setUserTokenMethod, "Method for set a custom token processing function")
 		// setSubstitutes Метод установки букв для исправления слов из смешанных алфавитов
 		.def("setSubstitutes", &anyks::Methods::setSubstitutes, "Method for set letters to correct words from mixed alphabets")
-		// getUserTokenScript Метод извлечения скрипта обработки пользовательских токенов
-		.def("getUserTokenScript", &anyks::Methods::getUserTokenScript, "Method for extracting a user token processing script")
 		// getTokensUnknown Метод извлечения списка токенов приводимых к <unk>
 		.def("getTokensUnknown", &anyks::Methods::getTokensUnknown, "Method for extracting a list of tokens reducible to <unk>")
 		// getSubstitutes Метод извлечения букв для исправления слов из смешанных алфавитов
@@ -1315,7 +1277,7 @@ PYBIND11_MODULE(alm, m) {
 		// setLocale Метод установки локали
 		m.def("setLocale", &anyks::Methods::setLocale, "Method set locale", py::arg("text") = L"en_US.UTF-8")
 		// idw Метод извлечения идентификатора слова
-		.def("idw", &anyks::Methods::idw, "Word ID Retrieval Method", py::arg("word") = L"", py::arg("check") = true)
+		.def("idw", &anyks::Methods::idw, "Word ID retrieval method", py::arg("word") = L"", py::arg("check") = true)
 		// setThreads Метод установки количества потоков
 		.def("setThreads", &anyks::Methods::setThreads, "Method for set the number of threads", py::arg("threads") = 0)
 		// read Метод чтения данных из файла arpa
